==> dirmngr_0.5.2.orig.tar.gz: dirmngr-0.5.2/src/crlfetch.h <==
/* crlfetch.h - LDAP access
 *      Copyright (C) 2002 Klarlvdalens Datakonsult AB
 *
 * This file is part of DirMngr.
 *
 * DirMngr is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * DirMngr is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#ifndef CRLFETCH_H
#define CRLFETCH_H

#include "../jnlib/types.h"
#include "../jnlib/strlist.h"
#include "dirmngr.h"


struct cert_fetch_context_s;
typedef struct cert_fetch_context_s *cert_fetch_context_t;


/* Fetch CRL from URL. */
gpg_error_t crl_fetch (const char* url, FILE **r_fp);

/* Fetch CRL for ISSUER using default server. */
gpg_error_t crl_fetch_default (const char* issuer, FILE **r_fp);


/* Fetch cert for DN. */
int ca_cert_fetch( const char* dn, unsigned char** value, size_t* valuelen );


/* Query the server for certs matching patterns. */
gpg_error_t start_cert_fetch (cert_fetch_context_t *context,
                              strlist_t patterns,
                              const ldap_server_t server);
gpg_error_t fetch_next_cert(cert_fetch_context_t context,
                            unsigned char **value, size_t *valuelen);
void end_cert_fetch (cert_fetch_context_t context);


/*-- ldap.c --*/
gpg_error_t attr_fetch_ldap( const char* dn, const char *attr,
                             unsigned char **value, size_t *valuelen );
gpg_error_t url_fetch_ldap(const char* url, const char* attr,
                           unsigned char **value, size_t *valuelen );

gpg_error_t start_cert_fetch_ldap(cert_fetch_context_t *context,
                                  strlist_t patterns,
                                  const ldap_server_t server );
gpg_error_t fetch_next_cert_ldap (cert_fetch_context_t context,
                                  unsigned char **value, size_t *valuelen );
void end_cert_fetch_ldap (cert_fetch_context_t context);


#endif /* CRLFETCH_H */

==> dirmngr_0.5.6.orig.tar.gz: dirmngr-0.5.6/src/crlfetch.h <==
/* crlfetch.h - LDAP access
 *      Copyright (C) 2002 Klarlvdalens Datakonsult AB
 *
 * This file is part of DirMngr.
 *
 * DirMngr is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * DirMngr is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#ifndef CRLFETCH_H
#define CRLFETCH_H

#include "../jnlib/types.h"
#include "../jnlib/strlist.h"
#include "dirmngr.h"


struct cert_fetch_context_s;
typedef struct cert_fetch_context_s *cert_fetch_context_t;


/* Fetch CRL from URL. */
gpg_error_t crl_fetch (const char* url, FILE **r_fp);

/* Fetch CRL for ISSUER using default server. */
gpg_error_t crl_fetch_default (const char* issuer, FILE **r_fp);


/* Fetch cert for DN. */
int ca_cert_fetch( const char *dn, FILE **r_fp);


/* Query the server for certs matching patterns. */
gpg_error_t start_cert_fetch (cert_fetch_context_t *context,
                              strlist_t patterns,
                              const ldap_server_t server);
gpg_error_t fetch_next_cert(cert_fetch_context_t context,
                            unsigned char **value, size_t *valuelen);
void end_cert_fetch (cert_fetch_context_t context);


/*-- ldap.c --*/
gpg_error_t attr_fetch_ldap( const char* dn, const char *attr, FILE **r_fp);
gpg_error_t url_fetch_ldap(const char* url, const char* attr,
                           unsigned char **value, size_t *valuelen );

gpg_error_t start_cert_fetch_ldap(cert_fetch_context_t *context,
                                  strlist_t patterns,
                                  const ldap_server_t server );
gpg_error_t fetch_next_cert_ldap (cert_fetch_context_t context,
                                  unsigned char **value, size_t *valuelen );
void end_cert_fetch_ldap (cert_fetch_context_t context);


#endif /* CRLFETCH_H */
